Small Magellanic Cloud CLI Tool
===============================

It is a command line tool and a Python library to access smallcloud.ai services.

Run your GPU-intensive tasks in a new way:

* Reserve GPUs from command line (or the web UI),

* Control your tasks easily,

* Add `import smallcloud` to your code and a few lines to automate the process.

Visit https://www.smallcloud.ai/ for details. Docs and tutorials are coming!
